# sphinx-godot

<a href="#">
  <img src="https://img.shields.io/badge/%F0%9F%94%96%20Version-0.0.5-ec3832.svg?color=ec3832&style=flat" />
</a>


## Installation

This theme is distributed on [PyPI][pypi] and can be installed with `pip`:

```shell
pip install sphinx-godot
```

To use the theme in your Sphinx project, you will need to edit your `conf.py` file’s `html_theme` setting:

```python
html_theme = "godot"
```
## License 📝

The theme is licensed under the [GPLv3](https://www.gnu.org/licenses/gpl-3.0.html).
See [LICENSE.md](LICENSE.md) for more details

It is also derived from the [Godot Engine][godot-engine]'s [documentation][godot-docs] dedicated [repository][godot-docs-repo].
See [THIRDPARTY.md](THIRDPARTY.md) for more details.

[godot-docs-repo]: https://github.com/godotengine/godot-docs
[godot-docs]: https://docs.godotengine.org
[godot-engine]: https://github.com/godotengine/godot
[pypi]: https://pypi.org/project/sphinx-godot